pub struct StartupMessage {
pub version: ProtocolVersion,
pub parameters: BTreeMap<String, String>,
pub parameter_pairs: Vec<(String, String)>,
}Fields
version: ProtocolVersionparameters: BTreeMap<String, String>parameter_pairs: Vec<(String, String)>Startup parameter pairs in wire order, including duplicate names.
Implementations
Sourceimpl StartupMessage
impl StartupMessage
pub fn get(&self, key: &str) -> Option<&str>
pub fn user(&self) -> Option<&str>
pub fn database(&self) -> Option<&str>
pub fn application_name(&self) -> Option<&str>
Sourcepub fn negotiate(
&self,
supported_protocol_options: &[&str],
) -> Result<StartupNegotiation, PgWireError>
pub fn negotiate( &self, supported_protocol_options: &[&str], ) -> Result<StartupNegotiation, PgWireError>
Negotiate a PostgreSQL 3.x minor version and report every _pq_.
startup option the embedding server has not implemented.
Sourcepub fn negotiate_with_max(
&self,
newest_supported: ProtocolVersion,
supported_protocol_options: &[&str],
) -> Result<StartupNegotiation, PgWireError>
pub fn negotiate_with_max( &self, newest_supported: ProtocolVersion, supported_protocol_options: &[&str], ) -> Result<StartupNegotiation, PgWireError>
Negotiate against the newest protocol version implemented by the embedding server.