pub struct ProtocolVersion {
pub major: u16,
pub minor: u16,
}Fields
major: u16minor: u16Implementations
Sourceimpl ProtocolVersion
impl ProtocolVersion
pub const V3_0: Self
pub const V3_2: Self
pub const LATEST: Self = Self::V3_2
pub fn from_raw(raw: i32) -> Self
pub const fn raw(self) -> i32
Sourcepub fn negotiate(self) -> Result<Self, PgWireError>
pub fn negotiate(self) -> Result<Self, PgWireError>
Select the newest protocol version this crate supports without negotiating to a version newer than the frontend requested.
Sourcepub fn negotiate_with_max(
self,
newest_supported: Self,
) -> Result<Self, PgWireError>
pub fn negotiate_with_max( self, newest_supported: Self, ) -> Result<Self, PgWireError>
Select a protocol version no newer than either the frontend request or the newest version implemented by the embedding server.
Sourcepub const fn is_supported_server_max(self) -> bool
pub const fn is_supported_server_max(self) -> bool
Versions an embedding server may configure as its implementation
maximum. PostgreSQL 18 has implementations for 3.0 and 3.2; a 3.1
frontend request can remain selected, but 3.1 is not a server maximum.